# 🔻 giza

🔻 `giza` is a Mathematical model for AI languages such as [`abcli`](https://github.com/kamangir/awesome-bash-cli) and [its ecosystem](https://github.com/kamangir). This model is described in the working paper "[Access, Automation, Analytics, AI](https://kamangir-public.s3.ca-central-1.amazonaws.com/giza-v1/giza.pdf)" [[tex](./tex/giza.tex)].

---

legacy version: "[A Related Set of Bash Expansions of Relevance to AI](https://kamangir-public.s3.ca-central-1.amazonaws.com/giza-v1/giza-5-115-1.pdf)" [[tex](https://github.com/kamangir/giza/tree/845ce1639af83ca86f536f31e2c18db8db5d052d)].

[![pylint](https://github.com/kamangir/giza/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/giza/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/giza/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/giza/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/giza/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/giza/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/gizai.svg)](https://pypi.org/project/gizai/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/gizai)](https://pypistats.org/packages/gizai)
